@@ -12,14 +12,17 @@ from power_cogs.utils import fullname
 class BaseConfigMixin:
     @classmethod
     def from_config_file(cls, config_path: str, overrides: Dict[str, Any] = {}):
-        _config_class = cls._config_class
-        loaded_config = load_config_from_file(
-            config_path, _config_class, overrides=overrides
-        )
-        loaded_config = asdict(loaded_config)
-        new_config = {"config": loaded_config}
-        new_config["_target_"] = fullname(cls)
-        return hydra.utils.instantiate(new_config, _recursive_=False)
+        try:
+            _config_class = cls._config_class
+            loaded_config = load_config_from_file(
+                config_path, _config_class, overrides=overrides
+            )
+            loaded_config = asdict(loaded_config)
+            new_config = {"config": loaded_config}
+            new_config["_target_"] = fullname(cls)
+            return hydra.utils.instantiate(new_config, _recursive_=False)
+        except Exception as e:
+            print("Caught exception when loading in file: {}".format(e))
 
     def instantiate(self, config: Dict[str, Any], recursive: bool = False) -> Any:
         return hydra.utils.instantiate(config, _recursive_=recursive)
