@@ -15,6 +15,7 @@ from power_cogs.base.base import Base
 from power_cogs.callbacks import after, before, callback
 from power_cogs.callbacks.class_method_callback import ClassMethodCallback
 from power_cogs.callbacks.save_checkpoint_callback import SaveCheckpointCallback
+from power_cogs.cluster.cluster import Cluster
 from power_cogs.cluster.local_cluster import LocalCluster
 from power_cogs.config.config import class_config
 from power_cogs.config.trainer_config import TrainerConfig
@@ -74,7 +75,7 @@ class BaseTorchTrainer(Base, metaclass=abc.ABCMeta):
         pass
 
     def setup_loggers(self):
-        self.loggers = [TensorboardLogger(logging_path=self.logging_path)]
+        self.logger = TensorboardLogger(logging_path=self.logging_path)
 
     def setup_trainer(self):
         pass
@@ -91,11 +92,19 @@ class BaseTorchTrainer(Base, metaclass=abc.ABCMeta):
     def setup_cluster(self):
         self.cluster = LocalCluster(self.cluster_config)
 
+    def attach_cluster(self, cluster: Cluster) -> None:
+        self.cluster = cluster
+
     """
         Train functions, ordering goes:
         pre_train -> train -> train_iter -> post_train
     """
 
+    def emit_metrics(self, out, step=0):
+        metrics = out["metrics"]
+        for key in metrics:
+            self.logger.tensorboard_writer.add_scalar(key, metrics[key], step)
+
     def pre_train(self):
         pass
 
@@ -112,10 +121,10 @@ class BaseTorchTrainer(Base, metaclass=abc.ABCMeta):
         raise NotImplementedError("train_iter not impemented!")
 
     @callback([SaveCheckpointCallback()])
-    @after([ClassMethodCallback("emit_metrics")])
     def _train_iter(self, batch_size: int = 32, epoch: int = 0):
         out = self.train_iter(batch_size, epoch)
         out["epoch"] = epoch
+        self.emit_metrics(out, epoch)
         return out
 
     @before([ClassMethodCallback("pre_train")])
@@ -140,10 +149,6 @@ class BaseTorchTrainer(Base, metaclass=abc.ABCMeta):
             bar.set_description(description)
         return metrics
 
-    def emit_metrics(self, output):
-        for logger in self.loggers:
-            logger.emit_metrics(output)
-
     ### helpers ###
     def _setup_checkpoint_paths(self):
         name = self.name
