@@ -112,10 +112,4 @@ class Cluster(Base, metaclass=abc.ABCMeta):
         pass
 
     def __call__(self, execution: Execution, *args, **kwargs) -> typing.Any:
-        if execution.__class__ not in self.__class__.ALLOWED_EXECUTIONS:
-            raise ValueError(
-                "Execution class {} not in allowlist {}".format(
-                    execution.__class__, self.__class__.ALLOWED_EXECUTIONS
-                )
-            )
         return self.execute(execution, *args, **kwargs)
