@@ -17,7 +17,7 @@ class LocalCluster(Cluster):
         pass
 
     def execute(self, execution, *args, **kwargs):
-        return [execution.execute(*args, **kwargs)]
+        return execution.execute(*args, **kwargs)
 
     def put(self, obj, name):
         self.cache[name] = obj
