@@ -43,7 +43,9 @@ class TrainerConfig(Config):
         self.stoppage_config.batch_size = self.batch_size
         self.stoppage_config.epochs = self.epochs
         self.stoppage_config.early_stoppage = self.early_stoppage
-        self.tune_config.checkpoint_freq = self.logging_config.checkpoint_interval
+        self.tune_config.tune_config.checkpoint_freq = (
+            self.logging_config.checkpoint_interval
+        )
 
 
 @dataclass
